<template>
  <div>
    <div id="sidebar">
      <recent-violations :violations="violations" />
      <suggestion-counter :suggestions="suggestions"/>
      <div id="headlines">
        <headlines />
      </div>
      <action-buttons
        :has-swiper="hasSwiper"
        :shop="shop" />
    </div>
    <div id="licenses" class="clearfix">
      <div id="maincontent">
        <h1>Business Licenses</h1>
        <section>
          <p>Please select the business for which you'd like to print a license.</p>
          <section class="shop">
            <div class="name">Print All Business Licenses</div>
            <a
              class="print button"
              @click.prevent="printLicenses('all')">Print Licenses</a>
          </section>
          <section
            v-for="(business, index) in businesses"
            :key="index"
            class="shop">
            <div class="name">{{ business.name }}: {{ business.title }}</div>
            <a @click.prevent="printLicenses(business)" class="print button">Print License</a>

          </section>
        </section>
      </div>
    </div>
  </div>
</template>

<script>
import RecentViolations from "./components/RecentViolation.vue";
import SuggestionCounter from "./components/SuggestionCounter.vue";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    RecentViolations,
    SuggestionCounter,
    Headlines,
    ActionButtons,
  },
  data() {
    return {
      businesses: [],
      intervalID: ''
    }
  },
  props: {
    suggestions: Array,
    violations: Array,
    shop: Object,
    hasSwiper: Boolean,
  },
  methods: {
    printLicenses(type) {
      if (type === 'all') {
        const args = {shops: this.businesses};
        confirm('Are you ready to print all business licenses?')
          ? app.printer.Enqueue('licenses', args)
          : alert('Print cancelled');
      } else {
        const args = {shops: []};
        args.shops.push(type);
        confirm(`Are you ready to print the ${type.name} license?`)
          ? app.printer.Enqueue('licenses', args)
          : alert('Print cancelled');
      }
    },
    getBusinesses() {
      this.intervalID = app.api.Get("shops/getAllWithPrettyNames/")
        .then( Response => {
          this.businesses = Response;
        })
        .catch( x => app.Message( x.error, "error" ) )
    },
    poller() {
      setInterval(() => {
        this.getBusinesses();
      }, 10000);
    }
  },
  created: function () {
    this.getBusinesses();
    this.poller();
  },
  destroyed: function () {
    clearInterval(this.intervalID);
  }
}
</script>

